<!-- markdownlint-disable -->

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\extras\style\themes.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `extras.style.themes`




**Global Variables**
---------------
- **TYPE_CHECKING**
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**

---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\extras\style\themes.py#L8"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `dark`

```python
dark() → QPalette
```






---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\extras\style\themes.py#L41"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `light`

```python
light() → QPalette
```






---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\extras\style\themes.py#L86"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `apply_theme`

```python
apply_theme(theme, widget)
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
